<?php

/**
 * UnitConversion: Lenght Conversion.
 *
 * @package WPDesk\AbstractShipping\Shipment
 */
namespace FedExVendor\WPDesk\AbstractShipping\UnitConversion;

use FedExVendor\WPDesk\AbstractShipping\Exception\UnitConversionException;
use FedExVendor\WPDesk\AbstractShipping\Shipment\Dimensions;
/**
 * Can convert length between different measure types
 */
class UniversalDimension
{
    /**
     * Length.
     *
     * @var float
     */
    private $length;
    /**
     * From unit.
     *
     * @var string
     */
    private $from_unit;
    /**
     * LengthConverter constructor.
     *
     * @param float $length Length.
     * @param string $from_unit From unit.
     *
     * @throws UnitConversionException Dimension exception.
     */
    public function __construct($length, $from_unit)
    {
        $this->length = $length;
        $this->from_unit = $from_unit;
    }
    /**
     * Convert to target unit. Returns 0 if confused.
     *
     * @param string $to_unit Target unit.
     *
     * @return float
     *
     * @throws UnitConversionException Dimension exception.
     */
    public function as_unit_rounded($to_unit)
    {
        $to_unit = \strtoupper($to_unit);
        if ($this->from_unit === $to_unit) {
            return $this->length;
        }
        if (empty($this->length)) {
            throw new \FedExVendor\WPDesk\AbstractShipping\Exception\UnitConversionException(\__('Dimension is null.', 'flexible-shipping-fedex'));
        }
        $unit_convert = [\FedExVendor\WPDesk\AbstractShipping\Shipment\Dimensions::DIMENSION_UNIT_IN => 25.4, \FedExVendor\WPDesk\AbstractShipping\Shipment\Dimensions::DIMENSION_UNIT_CM => 10];
        switch (\strtoupper($this->from_unit)) {
            case \FedExVendor\WPDesk\AbstractShipping\Shipment\Dimensions::DIMENSION_UNIT_IN:
                return \round($this->length * 25.4 / $unit_convert[$to_unit], 2);
            case \FedExVendor\WPDesk\AbstractShipping\Shipment\Dimensions::DIMENSION_UNIT_MM:
                return \round($this->length / $unit_convert[$to_unit], 2);
            default:
                // translators: %s to unit.
                throw new \FedExVendor\WPDesk\AbstractShipping\Exception\UnitConversionException(\sprintf(\__('Can\'t convert dimension to %s.', 'flexible-shipping-fedex'), $to_unit));
        }
    }
}
