<?php

/**
 * WooCommerce Logger: WooCommerceLogger class.
 *
 * @package WPDesk\WooCommerceShipping
 */
namespace FedExVendor\WPDesk\WooCommerceShipping;

use Psr\Log\LoggerInterface;
use Psr\Log\LoggerTrait;
use Psr\Log\LogLevel;
/**
 * Wants to show all logs using wc_add_notice
 */
class DisplayNoticeLogger implements \Psr\Log\LoggerInterface
{
    const WC_NOTICE = 'notice';
    const WC_ERROR = 'error';
    use LoggerTrait;
    /**
     * Logger.
     *
     * @var LoggerInterface
     */
    private $logger;
    /**
     * DisplayLogs constructor.
     *
     * @param \Psr\Log\LoggerInterface $logger Logger.
     */
    public function __construct(\Psr\Log\LoggerInterface $logger)
    {
        $this->logger = $logger;
    }
    /**
     * Logs with an arbitrary level.
     *
     * @param mixed  $level   Level.
     * @param string $message Message.
     * @param array  $context context.
     *
     * @return void
     */
    public function log($level, $message, array $context = [])
    {
        $this->logger->log($level, $message, $context);
        if (\in_array($level, [\Psr\Log\LogLevel::DEBUG, \Psr\Log\LogLevel::INFO], \true)) {
            $this->show($message, $context, self::WC_NOTICE);
        } else {
            $this->show($message, $context, self::WC_ERROR);
        }
    }
    /**
     * Show notices
     *
     * @param string $message Message.
     * @param array  $context context.
     * @param string $type    Type.
     *
     * @return void
     */
    private function show($message, array $context, $type)
    {
        $dump = '';
        foreach ($context as $label => $value) {
            if (!\is_string($value)) {
                $value = \print_r($value, \true);
            }
            $dump .= '<br/>' . '<div class="flexible-shipping-log">' . '<button class="show">' . \sprintf(\__('Show %1$s'), \ucfirst($label)) . '</button> ' . '<button class="hide">' . \sprintf(\__('Hide %1$s'), \ucfirst($label)) . '</button> ' . '<button class="clipboard">' . \sprintf(\__('Copy %1$s to clipboard'), \ucfirst($label)) . '</button> ' . '<pre>' . \esc_html($value) . '</pre>' . '</div>';
        }
        if (!\wc_has_notice($message . $dump, $type)) {
            \wc_add_notice($message . $dump, $type);
        }
    }
}
