<?php

/**
 * Trait with ShippingService static injection
 *
 * @package WPDesk\WooCommerceShipping\ShippingMethod\Traits
 */
namespace FedExVendor\WPDesk\WooCommerceShipping\ShippingMethod\Traits;

use Psr\Log\LoggerInterface;
use Psr\Log\NullLogger;
use FedExVendor\WPDesk\AbstractShipping\ShippingService;
use FedExVendor\WPDesk\WooCommerceShipping\DisplayNoticeLogger;
/**
 * Facilitates access to ShippingService abstract class with rates.
 *
 * @package WPDesk\WooCommerceShipping\ShippingMethod\Traits
 */
trait ShippingServiceTrait
{
    /**
     * Shipping service.
     *
     * @var ShippingService
     */
    protected static $shipping_service;
    /**
     * Set shipping service.
     *
     * @param ShippingService $shipping_service Shipping service.
     */
    public static function set_shipping_service(\FedExVendor\WPDesk\AbstractShipping\ShippingService $shipping_service)
    {
        self::$shipping_service = $shipping_service;
    }
    /**
     * Initializes and injects logger into service.
     *
     * @param ShippingService $service
     *
     * @return LoggerInterface
     */
    private function inject_logger_into(\FedExVendor\WPDesk\AbstractShipping\ShippingService $service)
    {
        if ($this->can_see_logs()) {
            $logger = new \FedExVendor\WPDesk\WooCommerceShipping\DisplayNoticeLogger(self::$logger);
        } else {
            $logger = new \Psr\Log\NullLogger();
        }
        $service->setLogger($logger);
        return $logger;
    }
}
